==> paraview-v4.3.0.zip: paraview-v4.3.0/Qt/Widgets/pqDoubleRangeDialog.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqDoubleRangeDialog.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef _pqDoubleRangeDialog_h
#define _pqDoubleRangeDialog_h

#include "pqWidgetsModule.h"

#include <QDialog>

class pqDoubleRangeWidget;

/// Provides a dialog for specifying a double between two ranges
class PQWIDGETS_EXPORT pqDoubleRangeDialog : public QDialog
{
  Q_OBJECT

public:
  pqDoubleRangeDialog(const QString &label,
                      double minimum,
                      double maximum,
                      QWidget *parent = 0);
  ~pqDoubleRangeDialog();

  void setValue(double value);
  double value() const;

private:
  pqDoubleRangeWidget *Widget;
};

#endif // !_pqDoubleRangeDialog_h

==> paraview-v5.9.1.zip: paraview-v5.9.1/Qt/Widgets/pqDoubleRangeDialog.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqDoubleRangeDialog.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef _pqDoubleRangeDialog_h
#define _pqDoubleRangeDialog_h

#include "pqWidgetsModule.h"

#include <QDialog>

class pqDoubleRangeWidget;

/**
* Provides a dialog for specifying a double between two ranges
*/
class PQWIDGETS_EXPORT pqDoubleRangeDialog : public QDialog
{
  Q_OBJECT

public:
  pqDoubleRangeDialog(const QString& label, double minimum, double maximum, QWidget* parent = 0);
  ~pqDoubleRangeDialog() override;

  void setValue(double value);
  double value() const;

private:
  pqDoubleRangeWidget* Widget;
};

#endif // !_pqDoubleRangeDialog_h
